@@ -39,5 +39,6 @@ __all__ = [
     'facial_beauty',
     'facial_beauty_short',
     'watermark_image_enhance',
-    'foreign_matter_removal'
+    'foreign_matter_removal',
+    'sh_face_enhancement'
 ]
